<?php

$lang['perm0'] = '%s ne peut pas lire cette page';
$lang['perm1'] = '%s peut lire cette page';
$lang['perm2'] = '%s peut éditer cette page';
$lang['perm4'] = '%s peut créer une page';
$lang['perm8'] = '%s peut charger un fichier';
$lang['perm16'] = '%s peut effacer cette page';
