<?php

$lang['perm0'] = '%s hat keine Rechte';
$lang['perm1'] = '%s hat Lese-Rechte';
$lang['perm2'] = '%s hat Schreib-Rechte';
$lang['perm4'] = '%s hat Anlege-Rechte';
$lang['perm8'] = '%s hat Upload-Rechte';
$lang['perm16'] = '%s hat Lösch-Rechte';
