<?php

$lang['perm0'] = '%s has no permissions';
$lang['perm1'] = '%s has read permissions';
$lang['perm2'] = '%s has edit permissions';
$lang['perm4'] = '%s has create permissions';
$lang['perm8'] = '%s has upload permissions';
$lang['perm16'] = '%s has delete permissions';
