<?php
/**
 * Korean language file
 *
 * @author Myeongjin <aranet100@gmail.com>
 */

$lang['perm0'] = '%s님은 권한이 없습니다';
$lang['perm1'] = '%s님은 읽기 권한을 가집니다';
$lang['perm2'] = '%s님은 편집 권한을 가집니다';
$lang['perm4'] = '%s님은 만들기 권한을 가집니다';
$lang['perm8'] = '%s님은 올리기 권한을 가집니다';
$lang['perm16'] = '%s님은 삭제 권한을 가집니다';
